@@ -9,11 +9,11 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.SimpleDB 1.20.0\n"
-        "Version:         1.20.0\n"
-        "Builder version: 6.1.2\n"
-        "Docs:            https://pypi.org/project/mypy-boto3-sdb/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/sdb.html#SimpleDB\n"
+        "Type annotations for boto3.SimpleDB 1.20.49\n"
+        "Version:         1.20.49\n"
+        "Builder version: 6.4.2\n"
+        "Docs:            https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb//\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sdb.html#SimpleDB\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
@@ -23,7 +23,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.20.0")
+    print("1.20.49")
 
 
 def main() -> None:
